@@ -38,7 +38,7 @@ public slots:
     void main();
 
 public:
-    explicit TestObject(QWidget* parent = 0, Qt::WindowFlags f = 0)
+    explicit TestObject(QWidget* parent = nullptr, Qt::WindowFlags f = {})
         : QWidget(parent, f)
     {
         QTimer::singleShot(0, this, SLOT(main()));
